@@ -9,14 +9,19 @@ def getSolcatcherTsUrl(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url='https://solcatcher.io/ts')
 def getSolcatcherDbCalls(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url="https://solcatcher.io/dbCalls")
-def get_db_header():
-    # Retrieve the key from environment variable or config
-    api_key = get_env_value('SOLCATCHER_DB_API_KEY')
-    # Make sure the server sees this header as "X-API-KEY"
-    return {
-        "X-API-KEY": api_key,
-        "Content-Type": "application/json"  # if your endpoint expects JSON
-    }
+def get_db_header(headers=None, api_key=None):
+    # Start with existing or default headers
+    headers = headers or {"Content-Type": "application/json"}
+
+    # Retrieve the key from environment or config
+    key = api_key or get_env_value('SOLCATCHER_DB_API_KEY')
+
+    # If key is not None, add the header; otherwise skip it
+    if key:
+        headers["X-API-KEY"] = str(key) if key else ""
+    # else do not set "X-API-KEY" at all
+
+    return headers
 def post_request(endpoint, **kwargs):
     url = getSolcatcherDbCalls(endpoint=endpoint)
     response = requests.post(url=url, data=json.dumps(kwargs), headers=get_headers())
